@@ -21,7 +21,7 @@ def main():
         print(Fore.RED + "Please reinstall Pie Manager." + Fore.RESET)
         exit()
 
-    new_pie = parent_dir(pie)
+    new_pie = parent_dir(pie_manager_path)
 
     # if os is windows
     if os.name == "nt":
